==> eam-wshub-proxyclient-11.5-3-sources.jar: net/datastream/schemas/mp_results/mp0044_001/MP0044_AddMeterReading_001_Result.java <==

package net.datastream.schemas.mp_results.mp0044_001;

import java.util.ArrayList;
import java.util.List;
import javax.xml.bind.annotation.XmlAccessType;
import javax.xml.bind.annotation.XmlAccessorType;
import javax.xml.bind.annotation.XmlElement;
import javax.xml.bind.annotation.XmlRootElement;
import javax.xml.bind.annotation.XmlType;
import net.datastream.schemas.mp_entities.meterreading_001.MeterReading;
import net.datastream.schemas.mp_fields.WOID_Type;


/**
 * <p>Classe Java pour anonymous complex type.
 * 
 * <p>Le fragment de schéma suivant indique le contenu attendu figurant dans cette classe.
 * 
 * <pre>
 * &lt;complexType>
 *   &lt;complexContent>
 *     &lt;restriction base="{http://www.w3.org/2001/XMLSchema}anyType">
 *       &lt;sequence>
 *         &lt;element name="ResultData">
 *           &lt;complexType>
 *             &lt;complexContent>
 *               &lt;restriction base="{http://www.w3.org/2001/XMLSchema}anyType">
 *                 &lt;sequence>
 *                   &lt;element ref="{http://schemas.datastream.net/MP_entities/MeterReading_001}MeterReading"/>
 *                   &lt;element ref="{http://schemas.datastream.net/MP_fields}ISWORKORDERCREATED"/>
 *                   &lt;element ref="{http://schemas.datastream.net/MP_fields}WORKORDERID" maxOccurs="unbounded" minOccurs="0"/>
 *                   &lt;element ref="{http://schemas.datastream.net/MP_fields}METERREADINGCODE" minOccurs="0"/>
 *                 &lt;/sequence>
 *               &lt;/restriction>
 *             &lt;/complexContent>
 *           &lt;/complexType>
 *         &lt;/element>
 *       &lt;/sequence>
 *     &lt;/restriction>
 *   &lt;/complexContent>
 * &lt;/complexType>
 * </pre>
 * 
 * 
 */
@XmlAccessorType(XmlAccessType.FIELD)
@XmlType(name = "", propOrder = {
    "resultData"
})
@XmlRootElement(name = "MP0044_AddMeterReading_001_Result")
public class MP0044_AddMeterReading_001_Result {

    @XmlElement(name = "ResultData", required = true)
    protected MP0044_AddMeterReading_001_Result.ResultData resultData;

    /**
     * Obtient la valeur de la propriété resultData.
     * 
     * @return
     *     possible object is
     *     {@link MP0044_AddMeterReading_001_Result.ResultData }
     *     
     */
    public MP0044_AddMeterReading_001_Result.ResultData getResultData() {
        return resultData;
    }

    /**
     * Définit la valeur de la propriété resultData.
     * 
     * @param value
     *     allowed object is
     *     {@link MP0044_AddMeterReading_001_Result.ResultData }
     *     
     */
    public void setResultData(MP0044_AddMeterReading_001_Result.ResultData value) {
        this.resultData = value;
    }


    /**
     * <p>Classe Java pour anonymous complex type.
     * 
     * <p>Le fragment de schéma suivant indique le contenu attendu figurant dans cette classe.
     * 
     * <pre>
     * &lt;complexType>
     *   &lt;complexContent>
     *     &lt;restriction base="{http://www.w3.org/2001/XMLSchema}anyType">
     *       &lt;sequence>
     *         &lt;element ref="{http://schemas.datastream.net/MP_entities/MeterReading_001}MeterReading"/>
     *         &lt;element ref="{http://schemas.datastream.net/MP_fields}ISWORKORDERCREATED"/>
     *         &lt;element ref="{http://schemas.datastream.net/MP_fields}WORKORDERID" maxOccurs="unbounded" minOccurs="0"/>
     *         &lt;element ref="{http://schemas.datastream.net/MP_fields}METERREADINGCODE" minOccurs="0"/>
     *       &lt;/sequence>
     *     &lt;/restriction>
     *   &lt;/complexContent>
     * &lt;/complexType>
     * </pre>
     * 
     * 
     */
    @XmlAccessorType(XmlAccessType.FIELD)
    @XmlType(name = "", propOrder = {
        "meterReading",
        "isworkordercreated",
        "workorderid",
        "meterreadingcode"
    })
    public static class ResultData {

        @XmlElement(name = "MeterReading", namespace = "http://schemas.datastream.net/MP_entities/MeterReading_001", required = true)
        protected MeterReading meterReading;
        @XmlElement(name = "ISWORKORDERCREATED", namespace = "http://schemas.datastream.net/MP_fields", required = true, defaultValue = "false")
        protected String isworkordercreated;
        @XmlElement(name = "WORKORDERID", namespace = "http://schemas.datastream.net/MP_fields")
        protected List<WOID_Type> workorderid;
        @XmlElement(name = "METERREADINGCODE", namespace = "http://schemas.datastream.net/MP_fields")
        protected String meterreadingcode;

        /**
         * Obtient la valeur de la propriété meterReading.
         * 
         * @return
         *     possible object is
         *     {@link MeterReading }
         *     
         */
        public MeterReading getMeterReading() {
            return meterReading;
        }

        /**
         * Définit la valeur de la propriété meterReading.
         * 
         * @param value
         *     allowed object is
         *     {@link MeterReading }
         *     
         */
        public void setMeterReading(MeterReading value) {
            this.meterReading = value;
        }

        /**
         * Obtient la valeur de la propriété isworkordercreated.
         * 
         * @return
         *     possible object is
         *     {@link String }
         *     
         */
        public String getISWORKORDERCREATED() {
            return isworkordercreated;
        }

        /**
         * Définit la valeur de la propriété isworkordercreated.
         * 
         * @param value
         *     allowed object is
         *     {@link String }
         *     
         */
        public void setISWORKORDERCREATED(String value) {
            this.isworkordercreated = value;
        }

        /**
         * Gets the value of the workorderid property.
         * 
         * <p>
         * This accessor method returns a reference to the live list,
         * not a snapshot. Therefore any modification you make to the
         * returned list will be present inside the JAXB object.
         * This is why there is not a <CODE>set</CODE> method for the workorderid property.
         * 
         * <p>
         * For example, to add a new item, do as follows:
         * <pre>
         *    getWORKORDERID().add(newItem);
         * </pre>
         * 
         * 
         * <p>
         * Objects of the following type(s) are allowed in the list
         * {@link WOID_Type }
         * 
         * 
         */
        public List<WOID_Type> getWORKORDERID() {
            if (workorderid == null) {
                workorderid = new ArrayList<WOID_Type>();
            }
            return this.workorderid;
        }

        /**
         * Obtient la valeur de la propriété meterreadingcode.
         * 
         * @return
         *     possible object is
         *     {@link String }
         *     
         */
        public String getMETERREADINGCODE() {
            return meterreadingcode;
        }

        /**
         * Définit la valeur de la propriété meterreadingcode.
         * 
         * @param value
         *     allowed object is
         *     {@link String }
         *     
         */
        public void setMETERREADINGCODE(String value) {
            this.meterreadingcode = value;
        }

    }

}

==> eam-wshub-proxyclient-11.7-3-sources.jar: net/datastream/schemas/mp_results/mp0044_001/MP0044_AddMeterReading_001_Result.java <==

package net.datastream.schemas.mp_results.mp0044_001;

import java.util.ArrayList;
import java.util.List;
import javax.xml.bind.annotation.XmlAccessType;
import javax.xml.bind.annotation.XmlAccessorType;
import javax.xml.bind.annotation.XmlElement;
import javax.xml.bind.annotation.XmlRootElement;
import javax.xml.bind.annotation.XmlType;
import net.datastream.schemas.mp_entities.meterreading_001.MeterReading;
import net.datastream.schemas.mp_fields.WOID_Type;


/**
 * <p>Java class for anonymous complex type.
 * 
 * <p>The following schema fragment specifies the expected content contained within this class.
 * 
 * <pre>
 * &lt;complexType>
 *   &lt;complexContent>
 *     &lt;restriction base="{http://www.w3.org/2001/XMLSchema}anyType">
 *       &lt;sequence>
 *         &lt;element name="ResultData">
 *           &lt;complexType>
 *             &lt;complexContent>
 *               &lt;restriction base="{http://www.w3.org/2001/XMLSchema}anyType">
 *                 &lt;sequence>
 *                   &lt;element ref="{http://schemas.datastream.net/MP_entities/MeterReading_001}MeterReading"/>
 *                   &lt;element ref="{http://schemas.datastream.net/MP_fields}ISWORKORDERCREATED"/>
 *                   &lt;element ref="{http://schemas.datastream.net/MP_fields}WORKORDERID" maxOccurs="unbounded" minOccurs="0"/>
 *                   &lt;element ref="{http://schemas.datastream.net/MP_fields}METERREADINGCODE" minOccurs="0"/>
 *                 &lt;/sequence>
 *               &lt;/restriction>
 *             &lt;/complexContent>
 *           &lt;/complexType>
 *         &lt;/element>
 *       &lt;/sequence>
 *     &lt;/restriction>
 *   &lt;/complexContent>
 * &lt;/complexType>
 * </pre>
 * 
 * 
 */
@XmlAccessorType(XmlAccessType.FIELD)
@XmlType(name = "", propOrder = {
    "resultData"
})
@XmlRootElement(name = "MP0044_AddMeterReading_001_Result")
public class MP0044_AddMeterReading_001_Result {

    @XmlElement(name = "ResultData", required = true)
    protected MP0044_AddMeterReading_001_Result.ResultData resultData;

    /**
     * Gets the value of the resultData property.
     * 
     * @return
     *     possible object is
     *     {@link MP0044_AddMeterReading_001_Result.ResultData }
     *     
     */
    public MP0044_AddMeterReading_001_Result.ResultData getResultData() {
        return resultData;
    }

    /**
     * Sets the value of the resultData property.
     * 
     * @param value
     *     allowed object is
     *     {@link MP0044_AddMeterReading_001_Result.ResultData }
     *     
     */
    public void setResultData(MP0044_AddMeterReading_001_Result.ResultData value) {
        this.resultData = value;
    }


    /**
     * <p>Java class for anonymous complex type.
     * 
     * <p>The following schema fragment specifies the expected content contained within this class.
     * 
     * <pre>
     * &lt;complexType>
     *   &lt;complexContent>
     *     &lt;restriction base="{http://www.w3.org/2001/XMLSchema}anyType">
     *       &lt;sequence>
     *         &lt;element ref="{http://schemas.datastream.net/MP_entities/MeterReading_001}MeterReading"/>
     *         &lt;element ref="{http://schemas.datastream.net/MP_fields}ISWORKORDERCREATED"/>
     *         &lt;element ref="{http://schemas.datastream.net/MP_fields}WORKORDERID" maxOccurs="unbounded" minOccurs="0"/>
     *         &lt;element ref="{http://schemas.datastream.net/MP_fields}METERREADINGCODE" minOccurs="0"/>
     *       &lt;/sequence>
     *     &lt;/restriction>
     *   &lt;/complexContent>
     * &lt;/complexType>
     * </pre>
     * 
     * 
     */
    @XmlAccessorType(XmlAccessType.FIELD)
    @XmlType(name = "", propOrder = {
        "meterReading",
        "isworkordercreated",
        "workorderid",
        "meterreadingcode"
    })
    public static class ResultData {

        @XmlElement(name = "MeterReading", namespace = "http://schemas.datastream.net/MP_entities/MeterReading_001", required = true)
        protected MeterReading meterReading;
        @XmlElement(name = "ISWORKORDERCREATED", namespace = "http://schemas.datastream.net/MP_fields", required = true, defaultValue = "false")
        protected String isworkordercreated;
        @XmlElement(name = "WORKORDERID", namespace = "http://schemas.datastream.net/MP_fields")
        protected List<WOID_Type> workorderid;
        @XmlElement(name = "METERREADINGCODE", namespace = "http://schemas.datastream.net/MP_fields")
        protected String meterreadingcode;

        /**
         * Gets the value of the meterReading property.
         * 
         * @return
         *     possible object is
         *     {@link MeterReading }
         *     
         */
        public MeterReading getMeterReading() {
            return meterReading;
        }

        /**
         * Sets the value of the meterReading property.
         * 
         * @param value
         *     allowed object is
         *     {@link MeterReading }
         *     
         */
        public void setMeterReading(MeterReading value) {
            this.meterReading = value;
        }

        /**
         * Gets the value of the isworkordercreated property.
         * 
         * @return
         *     possible object is
         *     {@link String }
         *     
         */
        public String getISWORKORDERCREATED() {
            return isworkordercreated;
        }

        /**
         * Sets the value of the isworkordercreated property.
         * 
         * @param value
         *     allowed object is
         *     {@link String }
         *     
         */
        public void setISWORKORDERCREATED(String value) {
            this.isworkordercreated = value;
        }

        /**
         * Gets the value of the workorderid property.
         * 
         * <p>
         * This accessor method returns a reference to the live list,
         * not a snapshot. Therefore any modification you make to the
         * returned list will be present inside the JAXB object.
         * This is why there is not a <CODE>set</CODE> method for the workorderid property.
         * 
         * <p>
         * For example, to add a new item, do as follows:
         * <pre>
         *    getWORKORDERID().add(newItem);
         * </pre>
         * 
         * 
         * <p>
         * Objects of the following type(s) are allowed in the list
         * {@link WOID_Type }
         * 
         * 
         */
        public List<WOID_Type> getWORKORDERID() {
            if (workorderid == null) {
                workorderid = new ArrayList<WOID_Type>();
            }
            return this.workorderid;
        }

        /**
         * Gets the value of the meterreadingcode property.
         * 
         * @return
         *     possible object is
         *     {@link String }
         *     
         */
        public String getMETERREADINGCODE() {
            return meterreadingcode;
        }

        /**
         * Sets the value of the meterreadingcode property.
         * 
         * @param value
         *     allowed object is
         *     {@link String }
         *     
         */
        public void setMETERREADINGCODE(String value) {
            this.meterreadingcode = value;
        }

    }

}
